==> projectx-sdk-1.0.10.3-20200316.024633-3-sources.jar: cn/com/duiba/projectx/sdk/demo/ProjectDemo.java <==
package cn.com.duiba.projectx.sdk.demo;

import cn.com.duiba.projectx.sdk.UserRequestContext;
import cn.com.duiba.projectx.sdk.annotation.ProjectConfig;
import cn.com.duiba.projectx.sdk.playway.JoinUserRequestApi;
import cn.com.duiba.projectx.sdk.playway.join.JoinPlaywayInstance;
import cn.com.duiba.projectx.sdk.project.HiddenPlaywayInstance;
import cn.com.duiba.projectx.sdk.project.HiddenSpInstance;

import java.lang.reflect.Method;

@ProjectConfig(enumSP = ProjectDemo.Abc.class,playways = {ProjectDemo.SignJoinPlayway.class, ProjectDemo.PlayJoinPlayway.class})
public class ProjectDemo {

    public static void main(String[] args) throws Exception{
        Class c=ProjectDemo.class;
        if(c.isAnnotationPresent(ProjectConfig.class)){
            ProjectConfig pc= (ProjectConfig) c.getAnnotation(ProjectConfig.class);
            Class<? extends HiddenPlaywayInstance>[] ps= pc.playways();
            for(Class<? extends HiddenPlaywayInstance> a:ps){
                System.out.println("playway:"+a);
            }

            Class<? extends HiddenSpInstance> sp=pc.enumSP();
            Method method=sp.getMethod("values");
            HiddenSpInstance is[]= (HiddenSpInstance[]) method.invoke(null,null);
            for(HiddenSpInstance i:is){
                System.out.println("sp:"+i.getId()+" name="+i.getName());
            }
        }

    }

    enum Abc implements HiddenSpInstance {
        P1("123","积分");
        private String id;
        private String name;
        private Abc(String id,String name){
            this.id=id;
            this.name=name;
        }

        public String getId() {
            return id;
        }

        public String getName() {
            return name;
        }
    }


    public class SignJoinPlayway extends JoinPlaywayInstance implements HiddenPlaywayInstance {

        @Override
        public Object doJoin(UserRequestContext context, JoinUserRequestApi api) {
            return null;
        }

        @Override
        public String getId() {
            return null;
        }

        @Override
        public String getName() {
            return null;
        }
    }

    public class PlayJoinPlayway extends JoinPlaywayInstance implements HiddenPlaywayInstance {

        @Override
        public Object doJoin(UserRequestContext context, JoinUserRequestApi api) {
            return null;
        }

        @Override
        public String getId() {
            return null;
        }

        @Override
        public String getName() {
            return null;
        }
    }
}

==> projectx-sdk-1.1.54-sources.jar: cn/com/duiba/projectx/sdk/demo/ProjectDemo.java <==
package cn.com.duiba.projectx.sdk.demo;

import cn.com.duiba.projectx.sdk.UserRequestContext;
import cn.com.duiba.projectx.sdk.annotation.ProjectConfig;
import cn.com.duiba.projectx.sdk.playway.JoinUserRequestApi;
import cn.com.duiba.projectx.sdk.playway.join.JoinPlaywayInstance;
import cn.com.duiba.projectx.sdk.project.HiddenPlaywayInstance;
import cn.com.duiba.projectx.sdk.project.HiddenSpInstance;

import java.lang.reflect.Method;

@ProjectConfig(enumSP = ProjectDemo.Abc.class,playways = {ProjectDemo.SignJoinPlayway.class, ProjectDemo.PlayJoinPlayway.class})
public class ProjectDemo {

    public static void main(String[] args) throws Exception{
        Class c=ProjectDemo.class;
        if(c.isAnnotationPresent(ProjectConfig.class)){
            ProjectConfig pc= (ProjectConfig) c.getAnnotation(ProjectConfig.class);
            Class<? extends HiddenPlaywayInstance>[] ps= pc.playways();
            for(Class<? extends HiddenPlaywayInstance> a:ps){
                System.out.println("playway:"+a);
            }

            Class<? extends HiddenSpInstance> sp=pc.enumSP();
            Method method=sp.getMethod("values");
//            HiddenSpInstance is[]= (HiddenSpInstance[]) method.invoke(null,null);
//            for(HiddenSpInstance i:is){
//                System.out.println("sp:"+i.getId()+" name="+i.getName());
//            }
        }

    }

    enum Abc implements HiddenSpInstance {
        P1("123","积分");
        private String id;
        private String name;
        private Abc(String id,String name){
            this.id=id;
            this.name=name;
        }

        public String getId() {
            return id;
        }

        public String getName() {
            return name;
        }
    }


    public class SignJoinPlayway extends JoinPlaywayInstance implements HiddenPlaywayInstance {

        @Override
        public Object doJoin(UserRequestContext context, JoinUserRequestApi api) {
            return null;
        }

        @Override
        public String getId() {
            return null;
        }

        @Override
        public String getName() {
            return null;
        }
    }

    public class PlayJoinPlayway extends JoinPlaywayInstance implements HiddenPlaywayInstance {

        @Override
        public Object doJoin(UserRequestContext context, JoinUserRequestApi api) {
            return null;
        }

        @Override
        public String getId() {
            return null;
        }

        @Override
        public String getName() {
            return null;
        }
    }
}
